(define-module (gnu packages glicid)
  #:use-module (guix packages)
  #:use-module (guix download)
  #:use-module (guix git-download)
  #:use-module (guix build-system gnu)
  #:use-module (guix build-system cmake)
  #:use-module (guix licenses)
  #:use-module (gnu packages gawk)
  #:use-module (gnu packages gcc)
  #:use-module (gnu packages commencement)
  #:use-module (guix build-system python)
  #:use-module ((guix licenses) #:prefix license:)
  #:use-module ((guix utils) #:select (target-64bit?))
  #:use-module (gnu packages)
  #:use-module (gnu packages admin)
  #:use-module (gnu packages autotools)
  #:use-module (gnu packages base)
  #:use-module (gnu packages freeipmi)
  #:use-module (gnu packages linux)
  #:use-module (gnu packages mpi)
  #:use-module (gnu packages perl)
  #:use-module (gnu packages pkg-config)
  #:use-module (gnu packages parallel)
  #:use-module (gnu packages storage)
  #:use-module (gnu packages networking)
  #:use-module (gnu packages gtk)  
  #:use-module (gnu packages python)
  #:use-module (gnu packages python-science)
  #:use-module (gnu packages python-web)
  #:use-module (gnu packages python-xyz)
  #:use-module (gnu packages readline)
  #:use-module (gnu packages tcl)
  #:use-module (gnu packages tls)
  #:use-module (gnu packages commencement)
  #:use-module (gnu packages gcc)
  #:use-module (gnu packages chemistry)
  #:use-module (gnu packages sphinx)
  #:use-module (srfi srfi-1)
  #:use-module (gnu packages mpi)
  #:use-module (gnu packages sssd)
  #:use-module (gnu packages fabric-management)
  #:use-module (gnu packages benchmark)
  #:use-module (gnu packages messaging)
  #:use-module (gnu packages web)
  #:use-module (gnu packages gnome))



(define-public glicid-custom-slurm-19.05
 (package 
  (inherit slurm) 
  (name "glicid-custom-slurm-19.05")
  (version "19.05.6")
  (source 
   (origin
    (method url-fetch)
    (uri (string-append "https://download.schedmd.com/slurm/slurm-" version ".tar.bz2"))
    (sha256 (base32 "1kj79r8hng5gp98ickgvj3im4gr19nzd3p3p8g6rl75axb8jin7h"))
   ))
   (inputs `(("gtk+-2" ,gtk+-2)
	     ("sssd", sssd)
		,@(package-inputs slurm)
  ))  
))

;; (define-public glicid-custom-slurm glicid-custom-slurm-19.05)

(define-public glicid-custom-slurm-20.02
 (package 
  (inherit glicid-custom-slurm-19.05)
  (name "glicid-custom-slurm-20.02")
  (version "20.02.2")
  (source 
   (origin
    (method url-fetch)
    (uri (string-append "https://download.schedmd.com/slurm/slurm-" version ".tar.bz2"))
    (sha256 (base32 "0bna1kyqphw6v7ca3gyfb3nlcpclc9vx8py55w7l7sv8xxsqrrvy"))
   ))
))




(define-public glicid-librdkafka-09
 (package 
  (inherit librdkafka) 
  (name "glicid-librdkafka-09")
  (version "0.9.2")
  (source 
   (origin
    (method url-fetch)
    (uri (string-append "https://github.com/edenhill/librdkafka/archive/v" version ".tar.gz"))
    (sha256 (base32 "0938yn1msaq8xcj5z7b3jcdy6rslh9kxmvz01r8rdcgbarlvchy2"))
   ))
))



(define-public glicid-x2go
 (package 
  (name "glicid-x2go")
  (version "4.1.0.3")
  (source 
   (origin
    (method url-fetch)
    (uri (string-append "https://code.x2go.org/releases/source/x2goserver/x2goserver-" version ".tar.gz"))
    (sha256 (base32 "1l6wd708kbipib4ldprfiihqmj4895nifg0bkws4x97majislxk7"))
   ))

    (native-inputs
     `(("autoconf" ,autoconf)
       ("automake" ,automake)
       ("libtool" ,libtool)))

   (inputs
    `(("perl" , perl)))

   (build-system gnu-build-system)
   (synopsis "X2go")
   (description "X2go")
   (license "not checked")
   (home-page "https://wiki.x2go.org")
  )  
)

;(define-public glicid-gromacs-openmpi
; (package
;  (inherit gromacs)
;  (name "glicid-gromacs-openmpi")
;  (inputs `(("openmpi", openmpi)
;                    ,@(package-inputs gromacs)))
;  (build-system cmake-build-system)
;  (arguments
;       `(#:configure-flags configure-flags)
;               (append configure-flags          (list "-DGMX_MPI=on"
;               "-DCMAKE_C_COMPILER=mpicc"
;               "-DCMAKE_CXX_COMPILER=mpiicxx"
;               ))
;  )
; )
;)


(define-public glicid-gromacs-openmpi
 (package
  (inherit gromacs)
  (name "glicid-gromacs-openmpi")
  (inputs `(("openmpi", openmpi)
   ;;         ("openssh", openssh) ;; only for tests... disabled now
                    ,@(package-inputs gromacs)))
  (build-system cmake-build-system)

   (arguments
       `(#:configure-flags
         (list "-DGMX_DEVELOPER_BUILD=on" ; Needed to run tests
               ;; Unbundling
               "-DGMX_USE_LMFIT=EXTERNAL"
               "-DGMX_BUILD_OWN_FFTW=off"
               "-DGMX_EXTERNAL_BLAS=on"
               "-DGMX_EXTERNAL_LAPACK=on"
               "-DGMX_EXTERNAL_TNG=on"
               "-DGMX_EXTERNAL_ZLIB=on"
               "-DGMX_EXTERNAL_TINYXML2=on"
               ;; special glicid
               "-DGMX_MPI=on"
               "-DCMAKE_C_COMPILER=mpicc"
               "-DCMAKE_CXX_COMPILER=mpicxx"
	       "-DGMX_DOUBLE=off"
	       "-DGMX_OPENMP=on"
               "-DGMX_SIMD=AVX2_256"
               (string-append "-DTinyXML2_DIR="
                              (assoc-ref %build-inputs "tinyxml2"))
               ;; Workaround for cmake/FindSphinx.cmake version parsing that does
               ;; not understand the guix-wrapped `sphinx-build --version' answer
               (string-append "-DSPHINX_EXECUTABLE_VERSION="
                              ,(package-version python-sphinx)))
         #:tests? #f
         #:phases
         (modify-phases %standard-phases
           (add-after 'unpack 'fixes
             (lambda* (#:key inputs #:allow-other-keys)
               ;; Still bundled: part of gromacs, source behind registration
               ;; but free software anyways
               ;;(delete-file-recursively "src/external/vmd_molfile")
               ;; Still bundled: threads-based OpenMPI-compatible fallback
               ;; designed to be bundled like that
               ;;(delete-file-recursively "src/external/thread_mpi")
               ;; Unbundling
               (delete-file-recursively "src/external/lmfit")
               (delete-file-recursively "src/external/clFFT")
               (delete-file-recursively "src/external/fftpack")
               (delete-file-recursively "src/external/build-fftw")
               (delete-file-recursively "src/external/tng_io")
               (delete-file-recursively "src/external/tinyxml2")
               (delete-file-recursively "src/external/googletest")
               (copy-recursively (assoc-ref inputs "googletest-source")
                                 "src/external/googletest")
               ;; This test warns about the build host hardware, disable
               (substitute* "src/gromacs/hardware/tests/hardwaretopology.cpp"
                 (("TEST\\(HardwareTopologyTest, HwlocExecute\\)")
                  "void __guix_disabled()"))
               #t)))))



  )

)



;; pour futures customisations.

;(define-public glicid-openmpi-gcc-10
; (package
;  (inherit openmpi)
;  (name "glicid-openpmi-gcc-10")
;  (inputs `(("gcc-10", gcc-10)
;            ("gfortran-10", gfortran-10)
;                  ,@(package-inputs openmpi)))
;  )
;)

(define-public glicid-rdma-core
(package
    (inherit rdma-core)
    (name "glicid-rdma-core")
    (version "31.0")
    (source (origin
              (method url-fetch)
              (uri (string-append "https://github.com/linux-rdma/rdma-core"
                                  "/releases/download/v" version "/rdma-core-"
                                  version ".tar.gz"))
              (sha256
               (base32
                "02ym93k6khfmzm9rml79x9zh1dy8231sygw16r287mhwp0x9mbji"))))
 )
)


(define-public glicid-rdma-core-gcc-10
(package
    (inherit rdma-core)
    (name "glicid-rdma-core-gcc-10")
    (version "31.0")
    (source (origin
              (method url-fetch)
              (uri (string-append "https://github.com/linux-rdma/rdma-core"
                                  "/releases/download/v" version "/rdma-core-"
                                  version ".tar.gz"))
              (sha256
               (base32
                "02ym93k6khfmzm9rml79x9zh1dy8231sygw16r287mhwp0x9mbji"))))
    (inputs `(("gcc-10", gcc-10)
      ,@(package-inputs rdma-core)))
 )
)


(define-public glicid-ucx-gcc-10
 (package
  (inherit ucx)
  (name "glicid-ucx-gcc-10")
  (version "1.9.0")
  (source 
   (origin
    (method url-fetch)
    (uri (string-append "https://github.com/openucx/ucx/releases/download/v" version "/ucx-" version ".tar.gz" ))
    (sha256 (base32 "1yrmwvjxi3najax1wz4irpzxns6cp74ksdx4i1049mf03n2ci8m7"))
   ))

  (inputs `(("gcc-10", gcc-10)
            ("gfortran-10", gfortran-10)
                  ,@(package-inputs ucx)))
  )
)




(define-public glicid-openmpi-gcc-10
 (package
  (inherit openmpi)
  (name "glicid-openpmi-gcc-10")
  (version "4.0.5")
  (source 
   (origin
    (method url-fetch)
    (uri (string-append "https://download.open-mpi.org/release/open-mpi/v4.0/openmpi-" version ".tar.gz"))
    (sha256 (base32 "01dxs4jrfl4x54g9vrxjp00ymf24gxp1d2hvdzqdfizx85s7fbjp"))
   ))

  (inputs `(("gcc-10", gcc-10)  
            ("gfortran-10", gfortran-10)
	    ("glicid-ucx-gcc-10",glicid-ucx-gcc-10)
;;            ("glicid-rdma-core",glicid-rdma-core) ;;; segfault !!! 
                  ,@(package-inputs openmpi)))
  )
)  

(define-public glicid-intel-mpi-benchmarks
 (package
  (inherit intel-mpi-benchmarks/openmpi)
  (name "glicid-intel-mpi-benchmarks")
  (inputs `(("glicid-openmpi-gcc-10", glicid-openmpi-gcc-10)  
                  ,@(package-inputs intel-mpi-benchmarks/openmpi)))
  )
)  




(define-public glicid-gromacs-gcc-10
 (package
  (inherit gromacs)
  (name "glicid-gromacs-gcc-10")
  (version "2020.3")
  (source 
   (origin
    (method url-fetch)
    (uri (string-append "http://ftp.gromacs.org/pub/gromacs/gromacs-" version ".tar.gz"))
    (sha256 (base32 "1acjrhcfzpqy2dncblhj97602jbg9gdha4q1bgji9nrj25lq6cch"))
   ))

  (inputs `(("gcc-10", gcc-10)
            ("gfortran-10", gfortran-10)
            ("glicid-openmpi-gcc-10", glicid-openmpi-gcc-10)
                    ,@(package-inputs gromacs)))
))


(define-public glicid-python-nbxmpp
 (package 
  (inherit python-nbxmpp) 
  (name "glicid-python-nbxmpp")
  (version "1.0.2")
  (source
     (origin
       (method url-fetch)
       (uri (pypi-uri "nbxmpp" version))
       (sha256
        (base32
         "0vw5drr077w9ks4crnw6pwa4735ycyjdcm54knc3w4in4x5027wr"))))

))


(define-public glicid-gajim
 (package
  (inherit gajim)
  (name "glicid-gajim")
  (version "1.2.2")
  (source 
   (origin
    (method url-fetch)
    (uri (string-append "https://gajim.org/downloads/1.2/gajim-" version ".tar.gz"))
    (sha256 (base32 "1gfcp3b5nq43xxz5my8vfhfxnnli726j3hzcgwh9fzrzzd9ic3gx"))
   ))

  (inputs `(("python-packaging", python-packaging)
            ("glicid-python-nbxmpp", glicid-python-nbxmpp)
	    ("python-css-parser", python-css-parser)
       ,@(package-inputs gajim)))

   (propagated-inputs
     `(
       ("glib-networking" ,glib-networking)
       ("libsoup" ,libsoup)
	))
))

(define-public glicid-specific-rdma-core-gcc-10
  (package
    (inherit rdma-core)
    (name "glicid-specific-rdma-core-gcc-10")
    (version "31.0")
    (source (origin
              (method url-fetch)
              (uri (string-append "https://github.com/linux-rdma/rdma-core"
                                  "/releases/download/v" version "/rdma-core-"
                                  version ".tar.gz"))
              (sha256
               (base32
                "02ym93k6khfmzm9rml79x9zh1dy8231sygw16r287mhwp0x9mbji"))))
      (inputs `(("gcc-10", gcc-10)
      ,@(package-inputs rdma-core)))



 )
)

(define-public glicid-specific-openmpi-gcc-10
  (package
    (inherit glicid-openmpi-gcc-10)
    (name "glicid-specific-openmpi-gcc-10")
      (inputs `(("glicid-specific-rdma-core-gcc-10",glicid-specific-rdma-core-gcc-10)
      ,@(package-inputs glicid-openmpi-gcc-10)))
)

(define-public glicid-specific-intel-mpi-benchmarks
 (package
  (inherit glicid-intel-mpi-benchmarks/openmpi)
  (name "glicid-specific-intel-mpi-benchmarks")
  (inputs `(("glicid-specific-openmpi-gcc-10", glicid-specific-openmpi-gcc-10)  
                  ,@(package-inputs glicid-intel-mpi-benchmarks)))
  )
)  





;;; glicid.scm ends here
